{% load static from staticfiles %}
<!doctype html>
<html class="no=js" {% block html_attrs %}{% endblock %}>
<head>
  <meta charset="UTF-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1" />
  <title>{% block title %}{% endblock %}{% block extratitle %}{% endblock %}</title>

  <!-- Style -->
  <link href='//fonts.googleapis.com/css?family=Roboto:900,400,300,700,500' rel='stylesheet' type='text/css' />
  <link rel="stylesheet" type="text/css" href="{% static 'asutheme/bootstrap/css/bootstrap.min.css' %}" />
  <link rel="stylesheet" type="text/css" href="{% static 'asutheme/asu/css/bootstrap-asu.min.css' %}" />
  <link rel="shortcut icon" href="{% static 'favicon.ico' %}" type="image/x-icon" />
  {% block extrastyle %}{% endblock %}

  <!-- HTML5 shim and Respond.js IE8 support of HTML5 elements and media queries -->
  <!--[if lt IE 9]>
  <script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
  <script src="https://oss.maxcdn.com/libs/respond.js/1.3.0/respond.min.js"></script>
  <![endif]-->

  <link type="text/css" rel="stylesheet" media="all" href="//www.asu.edu/asuthemes/4.3/css/asu_header.min.css" />
  <!--[if IE 9]>
  <style type="text/css">
    #asu_universal_nav ul ul{filter:none;box-shadow:0 6px 6px 0 #999}#asu_universal_nav>ul>li.parent:hover>a{filter:none;box-shadow:6px 0 6px -6px #999,-6px 0 6px -6px #999}
  </style>
  <![endif]-->

  <script src="//www.asu.edu/asuthemes/4.3/js/asu_header.min.js"></script>
  <script>
    var ASUHeader = ASUHeader || {};
    ASUHeader.browser = false;
  </script>
  <!--[if IE 5]><script>ASUHeader.browser = true;</script><![endif]-->
  <!--[if IE 6]><script>ASUHeader.browser = true;</script><![endif]-->
  <!--[if IE 7]><script>ASUHeader.browser = true;</script><![endif]-->
  <!--[if IE 8]><script>ASUHeader.browser = true;</script><![endif]-->
  <style type="text/css">
    #asu_hdr a { border-bottom: 0; }
  </style>
  {% block extrahead %}{% endblock %}
</head>

<body{% block body_attrs %}{% endblock %}>

  {% block asu_main_header %}
  <header id="asu_header">
    <div class="{{ asutheme_container_class }}">
      <!-- START /asuthemes/4.3/headers/default.shtml -->
      <div id="main-search" class="main-search closed"></div>
      <div id="asu_hdr" class="asu_hdr_white">
          <div id="asu_mobile_hdr">
            <div id="asu_logo">
              <a href="//www.asu.edu/" target="_top" title="Arizona State University">
              <img alt="Arizona State University" title="Arizona State University" src="//www.asu.edu/asuthemes/4.5/assets/full_logo.png"></a>
            </div>
              <div class="asuhide f-navicon" id="asu_mobile_button" onclick="javascript:ASUHeader.toggleASU();">
                  <a href="javascript:ASUHeader.toggleASU();">Menu</a>
              </div>
              <div class="f-search" id="search_new" onclick="javascript:ASUHeader.toggleASU('main-search');"></div>
          </div>
          <div class="closed" id="asu_mobile_menu">
              <div id="asu_nav_wrapper">
                  <h2 class="hidden">
                      Sign In / Sign Out
                  </h2>
                  <ul id="asu_login_module">
                      <li class="end" id="asu_hdr_ssi">
                          {% block asu_login_link %}
                          <a href="https://weblogin.asu.edu/cgi-bin/login" onclick="this.href=ASUHeader.alterLoginHref(this.href);" onfocus="this.href=ASUHeader.alterLoginHref(this.href);" onmouseover="this.href=ASUHeader.alterLoginHref(this.href);" target="_top">Sign In</a>
                          {% endblock %}
                      </li>
                  </ul>
                  <div id="asu_nav_menu">
                      <h2 class="hidden">
                          Menu
                      </h2>
                      <div id="asu_universal_nav">
                          <ul>
                              <li><a href="//www.asu.edu/" target="_top">ASU Home</a></li>
                              <li><a href="https://my.asu.edu/" target="_top">My ASU</a></li>
                              <li class="parent"><a href="//www.asu.edu/colleges/" target="_top">Colleges &amp; Schools</a>
                                  <ul>
                                      <li><a class="first" href="//artsandsciences.asu.edu/" target="_top" title="Arts and Sciences website">Arts and Sciences</a></li>
                                      <li><a href="//wpcarey.asu.edu/" target="_top" title="W. P. Carey School of Business Web and Morrison School of Agribusiness website">Business</a></li>
                                      <li><a href="//herbergerinstitute.asu.edu" target="_top" title="Herberger Institute for Design and the Arts website">Design and the Arts</a></li>
                                      <li><a href="//education.asu.edu/" target="_top" title="Mary Lou Fulton Teachers College website">Education</a></li>
                                      <li><a href="//engineering.asu.edu/" target="_top" title="Engineering website">Engineering</a></li>
                                      <li><a href="//graduate.asu.edu" target="_top" title="Graduate College website">Graduate</a></li>
                                      <li><a href="https://chs.asu.edu/" target="_top" title="Health Solutions website">Health Solutions</a></li>
                                      <li><a href="//honors.asu.edu/" target="_top" title="Barrett, The Honors College website">Honors</a></li>
                                      <li><a href="//cronkite.asu.edu" target="_top" title="Walter Cronkite School of Journalism and Mass Communication website">Journalism</a></li>
                                      <li><a href="//www.law.asu.edu/" target="_top" title="Sandra Day O' Connor College of Law website">Law</a></li>
                                      <li><a href="//nursingandhealth.asu.edu/" target="_top" title="College of Nursing and Health Innovation website">Nursing and Health Innovation</a></li>
                                      <li><a href="//copp.asu.edu" target="_top" title="College of Public Programs website">Public Service and Community Solutions</a></li>
                                      <li><a href="//schoolofsustainability.asu.edu" target="_top" title="School of Sustainability website">Sustainability</a></li>
                                      <li><a href="//uc.asu.edu/" target="_top" title="University College website">University College</a></li>
                      <li><a target="_top" href="http://www.thunderbird.edu/" title="Thunderbird School of Global Management website">New: Thunderbird School of Global Management</a></li>
                                  </ul>
                              </li>
                              <li class="parent"><a href="//www.asu.edu/map/" target="_top">Map &amp; Locations</a>
                                  <ul>
                                      <li><a class="border first" href="//www.asu.edu/map/" target="_top">Map</a></li>
                                      <li><a href="//campus.asu.edu/tempe/" target="_top" title="Tempe campus">Tempe</a></li>
                                      <li><a href="//campus.asu.edu/west/" target="_top" title="West campus">West</a></li>
                                      <li><a href="//campus.asu.edu/polytechnic/" target="_top" title="Polytechnic campus">Polytechnic</a></li>
                                      <li><a href="//campus.asu.edu/downtown/" target="_top" title="Downtown Phoenix campus">Downtown Phoenix</a></li>
                                      <li><a href="//asuonline.asu.edu/" target="_top" title="Online and Extended campus">Online and Extended</a></li>
                                      <li><a href="//havasu.asu.edu/" target="_top">Lake Havasu</a></li>
                      <li><a class="border" target="_top" href="http://www.thunderbird.edu/about-thunderbird/locations/phoenix-arizona">Thunderbird</a></li>
                                      <li><a href="//skysong.asu.edu/" target="_top">Skysong</a></li>
                                      <li><a href="//asuresearchpark.com/" target="_top">Research Park</a></li>
                                      <li><a href="//washingtoncenter.asu.edu/" target="_top">Washington D.C.</a></li>
                                      <li><a href="//wpcarey.asu.edu/mba/china-program/english/" target="_top">China</a></li>
                                  </ul>
                              </li>
                              <li><a href="//www.asu.edu/contactasu/" target="_top" title="Directory, Index and other info">Directory</a></li>
                          </ul>
                      </div>
                  </div>
              </div>
              <div id="asu_search">
                  <h2 class="hidden">
                      Search
                  </h2>
                  <div id="asu_search_module"></div>
              </div>
          </div>
      </div>
      <script type="text/javascript">
      <!--//--><![CDATA[//><!--
      ASUHeader.default_search_text = "Search ASU";
      ASUHeader.default_search_alttext = "Search ASU";
      if (typeof ASUHeader.signin_callback_url == "undefined") {
          ASUHeader.signin_callback_url = '';
      }
      if (typeof ASUHeader.signin_url == "undefined") {
          ASUHeader.signin_url = '';
      }
      if (typeof ASUHeader.signout_url == "undefined") {
          ASUHeader.signout_url = 'https://webapp4.asu.edu/myasu/Signout';
      }
      if (typeof ASUHeader.user_signedin == "undefined" || (ASUHeader.user_signedin != false && typeof ASUHeader.user_displayname == "undefined")) {
          ASUHeader.checkSSOCookie();
      }
      if (ASUHeader.user_signedin == true) {
          ASUHeader.setSSOLink();
      }
      if (navigator.userAgent.toLowerCase().indexOf('chrome') > -1) {
          document.getElementById('asu_hdr').className = document.getElementById('asu_hdr').className+" chrome";
      }
      //--><!]]>
      </script>
      <div style="clear:both;"></div>
      <!-- END /asuthemes/4.3/headers/default.shtml -->
    </div>
  </header>
  {% endblock asu_main_header %}

  {% block site_name %}
  <div id="site-name-desktop" class="section site-name-desktop">
    <div class="{{ asutheme_container_class }}">
      <h1 class="site-title" id="asu_school_name">
        <span class="first-word">
          {% block asu_site_title_main %}{% endblock %}
        </span>
        {% block asu_site_title_extra %}{% endblock %}
      </h1>
    </div>
  </div>
  {% endblock %}

  {% block navbar %}
  <nav class="navbar navbar-ws" role="navigation">
    <div class="{{ asutheme_container_class }}">
      <div class="navbar-header">
        <button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#ws-navbar-collapse-1">
          <span class="sr-only">Toggle navigation</span>
          <span class="icon-bar"></span>
          <span class="icon-bar"></span>
          <span class="icon-bar"></span>
        </button>
        <a class="navbar-brand" href="/">{% block navbar_brand_link_text %}{% endblock %}</a>
      </div>
      <div id="ws-navbar-collapse-1" class="collapse navbar-collapse">
        <ul id="menu-header-menu" class="nav navbar-nav">
          <li>
            <a href="/" title="Home">
              <span class="fa fa-home hidden-xs hidden-sm" aria-hidden="true"></span><span class="hidden-md hidden-lg">Home</span>
            </a>
          </li>
          {% block navbar_content %}{% endblock %}
        </ul>
      </div>
    </div>
  </nav>
  {% endblock %}

  <div id="main-wrapper" class="clearfix">
    <div id="main" class="clearfix">
      <div id="content" class="site-content">
          {% block main_content %}{% endblock %}
      </div>
    </div>
  </div>

  {% block footer %}
  <footer class="footer">

    {% block super_footer %}
    <div class="big-foot">
      <div class="{{ asutheme_container_class }}">
        <div class="row">
          {% block super_footer_brand_col %}
          <div class="col-md-4 col-sm-12 space-bot-md">
            {% block super_footer_brand %}{% endblock %}
          </div>
          {% endblock %}
          {% block super_footer_content %}{% endblock %}
        </div>
      </div>
    </div>
    {% endblock %}

    {% block global_footer %}
    <div class="little-foot">
      <div class="{{ asutheme_container_class }}">
        <div class="row">
          <div class="col-md-12">
            <ul class="little-foot-nav">
              <li><a href="http://www.asu.edu/copyright/">Copyright &amp; Trademark</a></li>
              <li><a href="http://www.asu.edu/accessibility/">Accessibility</a></li>
              <li><a href="http://www.asu.edu/privacy/">Privacy</a></li>
              <li><a href="http://www.asu.edu/asujobs">Jobs At ASU</a></li>
              <li><a href="https://cfo.asu.edu/emergency">Emergency</a></li>
              <li><a href="https://contact.asu.edu/">Contact ASU</a></li>
            </ul>
          </div>
        </div>
      </div>
    </div>
    {% endblock %}

  </footer>
  {% endblock %}

  <script src="{% static 'asutheme/jquery/jquery.min.js' %}"></script>
  <script src="{% static 'asutheme/bootstrap/js/bootstrap.min.js' %}"></script>
  {% block extrajs %}{% endblock %}

  {% block google_analytics %}
  <script>
    (function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
    (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
    m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
    })(window,document,'script','//www.google-analytics.com/analytics.js','ga');

    ga('create', '{% block google_analytics_tracking_id %}{% endblock %}', 'auto');
    ga('send', 'pageview');
  </script>
  {% endblock %}

  </body>
</html>
